<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>Application</name>
    <message>
        <location filename="../main.cpp" line="191"/>
        <source>File Manager</source>
        <translation>Menedżer plików</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="195"/>
        <source>File Manager is a powerful and easy-to-use file management tool, featured with searching, copying, trash, compression/decompression, file property and other useful functions.</source>
        <translation>Menedżer plików to potężne i łatwe w użyciu narzędzie do zarządzania plikami, wyposażone w wyszukiwanie, kopiowanie, kosz, kompresję/dekompresję, właściwości pliku i inne przydatne funkcje.</translation>
    </message>
</context>
</TS>